#
# spec file for package libindi
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver 1

%define _udevdir %(pkg-config --variable udevdir udev)

Name:           libindi
Version:        1.2.0
Release:        1.2
Summary:        Instrument Neutral Distributed Interface
License:        GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Scientific/Astronomy
Url:            http://www.indilib.org/
Source0:        http://downloads.sourceforge.net/indi/%{name}_%{version}.tar.gz
# PATCH-FIX-UPSTREAM no-return-in-nonvoid-function.patch asterios.dramis@gmail.com -- Fix "no-return-in-nonvoid-function" post-build check errors
Patch0:         no-return-in-nonvoid-function.patch
Patch1:         libindi-implicit-pointer-decl.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  gsl-devel
BuildRequires:  libcfitsio-devel
BuildRequires:  libcurl-devel
BuildRequires:  libfli-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libnova-devel
%if 0%{?suse_version} >= 1140
BuildRequires:  pkgconfig(udev)
%else
BuildRequires:  pkg-config
BuildRequires:  udev
%endif
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libusb-1.0)
Requires:       libindi%{so_ver} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package devel
Summary:        Development files for libindi
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libindi%{so_ver} = %{version}
Requires:       libindiAlignmentDriver%{so_ver} = %{version}
Requires:       libindidriver%{so_ver} = %{version}

%description devel
This package contains development files for libindi.

%package -n libindi%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindi%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindiAlignmentDriver%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindiAlignmentDriver%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%package -n libindidriver%{so_ver}
Summary:        Instrument Neutral Distributed Interface
Group:          System/Libraries

%description -n libindidriver%{so_ver}
INDI is an Instrument Neutral Distributed Interface control protocol
for astronomical devices, which provides a framework that decouples low
level hardware drivers from high level front end clients. Clients that
use the device drivers are completely unaware of the device
capabilities and communicate with the device drivers and build a
completely dynamic GUI based on the services provided by the device.

%prep
%setup -q -n %{name}_%{version}
%patch0 -p1
%patch1 -p1

%build
mkdir build
cd build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
_libsuffix=$(echo %_lib | cut -b4-)
cmake \
 -DCMAKE_INSTALL_PREFIX=%{_prefix} \
 -DLIB_SUFFIX="$_libsuffix" \
 -DUDEVRULES_INSTALL_DIR=%{_udevdir}/rules.d \
 ..
make %{?_smp_mflags} VERBOSE=1
cd ..

%install
%cmake_install

%post -n libindi%{so_ver} -p /sbin/ldconfig

%postun -n libindi%{so_ver} -p /sbin/ldconfig

%post -n libindiAlignmentDriver%{so_ver} -p /sbin/ldconfig

%postun -n libindiAlignmentDriver%{so_ver} -p /sbin/ldconfig

%post -n libindidriver%{so_ver} -p /sbin/ldconfig

%postun -n libindidriver%{so_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING.* COPYRIGHT ChangeLog LICENSE NEWS README TODO
%{_datadir}/indi/
%{_bindir}/indi*
%{_udevdir}/rules.d/*.rules

%files devel
%defattr(-,root,root,-)
%doc COPYING.GPL COPYING.LGPL LICENSE
%{_includedir}/libindi/
%{_libdir}/pkgconfig/libindi.pc
%{_libdir}/libindi*.so
%{_libdir}/libindi*.a

%files -n libindi%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/indi/
%{_libdir}/libindi.so.%{so_ver}*

%files -n libindiAlignmentDriver%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libindiAlignmentDriver.so.%{so_ver}*

%files -n libindidriver%{so_ver}
%defattr(-,root,root,-)
%{_libdir}/libindidriver.so.%{so_ver}*

%changelog
* Sun Jun 26 2016 asterios.dramis@gmail.com
- Update to version 1.2.0:
  * Support for Davis Vantage Pro/Pro2/Vue Weather Station.
  * Support for XAGYL Filter Wheel.
  * Support for Optec Flip Flat.
  * Support for Pulasr2 mount.
  * Support for JMI Smart Focus.
  * Support for GPS driver based on gpsd.
  * 3rdParty: QHY Updates and Fixes. Color camera support.
  * 3rdParty: GPhoto focus and live streaming fixes.
  * 3rdParty: Starlight Xpress support for multiple identical
    devices and driver improvements.
  * 3rdParty: ASI updated to latest SDK. Temperature readout for
    all cameras. ROI & Cooler fixes.
  * FocusLynx: Support 2 focusers.
  * Celestron: Support pulse guiding. Support hibernation and wakup
    on supported firmware.
  * SynScan: Complete rewrite to support latest features in the
    firmware.
  * GPhoto: Mirror lock support before capture.
  * RoboFocus: Update to comply to INDI::Focus standards.
  * SBIG: Support for connecting to Ethernet based CCDs.
  * ZEQ25: Updates and fixes.
  * MaxDomeII: Driver updated and tested under latest INDI::Dome
    standards.
  * QSI: Added anti-blooming option.
  * INDI WatchDog driver: Can be configured to perform observatory
    shutdown.
  * EQMod: Initial support for INDI Alignment Subsystem. Do not
    stop motor in low speed (guiding issue).
  * Temma: Complete rewrite based on INDI::Telescope and using INDI
    Alignment Subsystem.
  * AutoDome park feature in Dome devices.
  * Fix Crash on ODroid.
  * Added Meta-Weather driver to aggregate weather data from
    multiple sources.
  * Support for remotely controller dust caps and light box devices.
  * Handle 16bit images in Rapid Guide mode.
  * BaseClient non-blocking connect support.
  * Unified Streaming/Recording support for multiple drivers
    (ASI/QHY/V4L2).
  From version 1.1.0:
  * INDI::Weather for support of weather devices.
  * INDI::GPS for support of GPS devices.
  * WunderGround weather driver.
  * Meade DSI I & II support.
  * FocusLynx focuser support.
  * PerfectStar focuser support.
  * World Coordinate System (WCS) support in generated FITS.
  * Updated Losmany driver.
  * New Celestron driver.
  * New IEQPro driver.
  * Support for custom parking in dome drivers.
  * Support Open Loop dome controllers.
  * Various QHY CCD & Filter Wheel fixes and QHY OSX support.
  * SBIG External Guide CCD fixes.
  * Custom parking support for
    Celestron/Astrophysics/AstroElectronics/IEQPro
  * Updated ASI ZWO drivers.
  * Updated Apogee library. Improved NET support in INDI Apogee
    driver.
  * Standarizing mount slew and track rates.
  * Video4Linux 2 fixes and improvements: (16bpp pixel formats(Y16
    and BYR2), pwc flashled, colorSpace/linearization, stacking),
    Simutaneous record/stream/exp. Stream rate divisor. Rec. file
    patterns.
  * EQMod fixes: Keep tracking after joystick motion is stopped.
    Park initialization always set encoders.
  * Improved support for drivers on ARM architecture.
  * Improved logging capability.
  * Deprecated: LX200Legacy and indimain library.
- Rebased libindi-implicit-pointer-decl.patch to apply cleanly.
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Added new build requirement libcurl-devel.
* Sun Jul  5 2015 crrodriguez@opensuse.org
- libindi-implicit-pointer-decl.patch: fix rpmlint implicit
  declaration warnings
- BuildRequire libusb-1.0 not libusb-devel
- Build C++ code with at least -fvisibility-inlines-hidden.
* Sat Feb 21 2015 asterios.dramis@gmail.com
- Update to version 1.0.0:
  * 3rdparty: Support for QHY CCDs and CFWs (BETA).
  * 3rdparty: Support for Meade DSI (BETA).
  * 3rdparty: Support for FFMV cameras.
  * Support for STAR2000.
  * Support for Baader dome.
  * Support for Baader SteelDrive focuser.
  * Support for dome slaving (BETA).
  * Subframing and debayer support in GPhoto driver.
  * Improved CFW handling and external tracking CCD for SBIG CCDs.
  * Add debayer support for color cameras with user-configurable
    options. Debayer is performed at the client level.
  * Fixed deinterlacing and subframing support in Starlight Xpress
    drivers.
  * Fixed issues with joystick support in some drivers. Added
    joystick support to focuser and filter wheels.
  * Improvements in generation of FITS header.
  * Improvement in performance of some drivers under SBCs like
    Raspberry PI.
  * Added fan and readout speed controls to QSI CCD.
  * Fixed locale issue in INDI driver.
  * Fixed regression in LX200Basic driver.
  * Fixed issue with INDI Server resetting environment variable for
    skeleton and config files.
  * Various fixes for loading/saving of user configuration.
  From version 0.9.9:
  * Thread-safe INDI Library.
  * Support for Rigelsys NFocus Focuser driver.
  * 3rdparty: Additional VID/PID for QHY.
  * 3rdparty: added USB Bandiwdth control for ZWO Optical cameras.
  * 3rdparty: Updated and improved INDI Apogee driver and Apogee
    Library major update.
  * 3rdparty: Live preview support for GPhoto driver. Tested on
    Canon.
  * 3rdparty: Various bugfixes and improvements in INDI SBIG driver
    including working guide chip support.
  * 3rdparty: Fixed time drift error in EQMod. Added Horizon
    limits. Added Backlash comp.
  * Updated and improved Image Agent.
  * Improved Astrophysics driver support.
  * Fixed location bug in Celestron GPS driver.
  * Additional information in FITS header such as filter name.
  * Joystick support for focuser and filter wheel devices.
  * Added option to enable local & remote save for FITS images in
    all CCD drivers.
  * Older V4L driver is deprecated (indi_v4l_legacy) and is
    replaced by indi_v4l2_ccd
  * V4L2: added recording (SER files) for use with Registax
  * V4L2: added RGGB & UYVY pixel format support to V4L2 drivers.
  * V4L2: fixed LX long exposure times.
  * Updated and improved tutorials.
  * Fixed few OSX compatibility issues.
  * Various bug fixes and improvements.
  From version 0.9.8:
  * Support for Telescope Alignment Subsystem Infrastructure. This
    includes an implementation of Markley's singular value
    decomposition (SVD) based algorithm for the computation of
    sky/telescope coordinate conversion transforms, in addition to
    multiple plugin support.
  * Suppprt for SkyWatcherAPI Mount with Alignment Subsystem.
  * Support for ZWO Optics ASI Cameras (3rd party)
  * Support for AAG Cloud Watcher station (3rd Party).
  * Support for MoonLite focusers.
  * Support for Fishcamp CCDs (3rd Party).
  * Support for Imager Agent.
  * Improved EQMod driver including custom parking position.
  * New and updated Astrophysics mount driver.
  * New and updated QHY CCD Driver (3rd Party).
  * New and improved GPhoto driver to support DSLRs.
  * New and updated Video4Linux CCD Driver including support for
    long exposures (LX) and Imaging Source cameras.
  * New and improved Apogee CCD driver.
  * Improved support for SBIG CCDs including ST-I.
  * Updated and improved TCFS Focuser drivers.
  * Drivers migrated to libusb 1.0 framework.
  * Rapid Guide Support for CCD Drivers.
  * Improved compatibility with Mac OSX including INDI Server and
    GUI.
  * Various bug fixes and improvements.
- Added new build requirements gsl-devel and libjpeg-devel.
- Adjust no-return-in-nonvoid-function.patch for this release
  (patch upstream).
- Removed libindi-aarch64.patch (fixed upstream).
* Sat Feb  1 2014 hrvoje.senjan@gmail.com
- Update to version 0.9.7:
  * Support for EQMod mount driver (3rd party).
  * Support for ATIK CCDs and Filter Wheels (3rd party).
  * Support for Shoestring Astronomy FCUSB (3rd party).
  * Support for joysticks and game pads under Linux.
  * LX200, Celeston, and EQMod drivers support joystick input.
  * Improved LX200 & Celestron telescope drivers.
  * Improved simulator drivers.
  * INDI server support for multiple devices per driver.
  * New universal logging and debugging framework for INDI
    developers.
  * Fixed an issue in TCFS driver where a connect may fail if
    focuser is put into sleep mode.
  * Fixed an issue where the client thread in INDI::BaseClient
    is not being terminated gracefully in blocking mode.
  * Fixed an issue involving non-English clients that utilize
    INDI client library to communicate with INDI server.
  * Fixed an issue where some properties in some drivers are
    sent before getting defined by INDI.
- Droped udev_rules_dir_configurable.patch, not required anymore
- Adjust no-return-in-nonvoid-function.patch for this release
* Wed Mar 27 2013 schwab@suse.de
- libindi-aarch64.patch: No port I/O on aarch64
* Wed Nov 28 2012 asterios.dramis@gmail.com
- Update to version 0.9.6:
  * Support for Starlight Xpress Adaptive Optics unit.
  * Improved support for Startlight Xpress CCDs and Filter wheels.
  * Support for Arduino boards, with customizable drivers for common
    observatory auxiliary devices.
  * Support for GPUSB Guide Port Interface.
  * Improved support for QSI CCDs and Filter wheels.
  * Support for filters with absolute positioning.
  * Support for cameras with guiding chip.
  * Fixed INDI server FIFO CPU utilization bug.
  * Fixed various bugs with v4l drivers due to code regression.
  * Improved support for Mac OS X.
  * Improved simulators.
  * _REQUEST properties are now deprecated.
  * Updated tutorials and API.
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix some new "no-return-in-nonvoid-function" rpm
  post-build check errors.
- Added a patch (udev_rules_dir_configurable.patch) to make
  "UDEVRULES_INSTALL_DIR" configurable.
- Added pkgconfig(udev) as build requirement in order to install the udev rules
  file in the correct directory.
* Thu Sep 27 2012 asterios.dramis@gmail.com
- Update to version 0.9.5:
  * Focuser simulator driver.
  * CCD, Telescope, Focuser, and Filter simulators improvements including
    periodic error effects, FWHM, and more.
  * Major improvements to INDI Base Library and INDI Client Library.
  * Fixed minor bugs in LX200 Generic, LX200 FS2, Magellan, and Celestron
    drivers.
  * Minor bugfixes and improvements.
  * Fixed color buffer problem in V4L drivers.
  * Numerous bug fixes and minor improvements.
  From 0.9.1:
  * Bugfix release.
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix some new "no-return-in-nonvoid-function" rpm
  post-build check errors.
- Removed libindi-usleep.patch that fixed compilation with gcc-4.7 (fixed
  upstream).
* Tue May 22 2012 asterios.dramis@gmail.com
- Removed cfitsio_link_libs.patch (not needed after the update of cfitsio
  package and cfitsio.pc fix regarding library linking).
* Wed Mar 14 2012 asterios.dramis@gmail.com
- Added a patch (taken from Fedora) to fix compilation with gcc-4.7.
* Thu Jan 19 2012 asterios.dramis@gmail.com
- Update to version 0.9:
  * INDI::Base drivers are now used for most classes of astronomical
    instruments.
  * New iEQ45 GoTo German Equatorial Mount Driver.
  * New improved QSI CCD & Filter driver.
  * New improved Starlight Xpress CCD & Filter driver.
  * New improved RoboFocus driver.
  * libboost is no longer required to build libindi.
  * Improved support for building on non-Linux OSes.
  * Numerous bug fixes and minor improvements.
- Removed the following patches:
  * bufferoverflowstrncat.patch (fixed upstream).
  * fix_symlinks.patch (fixed upstream).
  * libindi.pc_fix.patch (fixed upstream).
- Removed the previous no-return-in-nonvoid-function.patch (fixed upstream) and
  added a new one to fix a new "no-return-in-nonvoid-function" rpm post-build
  check error.
- Replaced libindi-cfitsio.patch with cfitsio_link_libs.patch (fix missing
  "pthread" in target_link_libraries where needed).
- Spec file updates:
  * Removed boost-devel from BuildRequires (not needed anymore).
* Mon Dec 12 2011 idonmez@suse.com
- Fix build with new cfitsio
* Sun Sep 18 2011 asterios.dramis@gmail.com
- Update to version 0.8:
  * Starlight Xpress CCD and Filter Wheel.
  * EQ Synscan Mount.
  * TCFS Focuser.
  * QSI CCD.
  * Radio Astronomy Supplies Spectracyber Hydrogen Line Spectromet.
  From 0.7.1/0.7.2:
  * Fixed change filter bug in true technology filter wheel.
  * setINDI updated and improved.
  * Improved INDI::Mediator functionality.
  * Fixed buffer reading in INDI::BaseClient.
  * Add new tutorial for INDI::BaseClient.
  From 0.7.0:
  * Dynamic renaming of drivers upon run time.
  * Standard helper API to create and utilize INDI clients.
  * Ability to load driver properties from an external XML file.
  * Ability to write/read XML configuration files for driver values to be
    loaded at run time.
  * Facilitating debugging and simulation of drivers.
  * New C++ framework to facilitate the development of new INDI drivers.
  * New 3rd party drivers!
  * Several bug fixes for current drivers and framework.
- Spec file updates:
  * Added boost-devel in BuildRequires.
- Added 2 patches to fix rpm post-build check errors "bufferoverflowstrncat"
  and "no-return-in-nonvoid-function".
* Sat May 21 2011 asterios.dramis@gmail.com
- Update to version 0.6.2:
  * Build related updates.
  From 0.6.1:
  * Updating drivers.xml to comply to new XML structure for group and devices
    metadata descriptions.
- Spec file updates:
  * Changes based on spec-cleaner run.
  * Changes in Url, Group, Summary and %%description.
  * Changes in the fix for lib64 installation.
  * Minor other updates.
- Added 2 patches to fix the symlinks installation and the pkgconfig file based
  on Gentoo.
* Thu Apr  1 2010 llunak@novell.com
- Add libfli as a buildrequire
* Fri Mar 20 2009 crrodriguez@suse.de
- run ldconfig
- use RPM_OPT_FLAGS
- fix -devel package dependencies
* Tue Jan  6 2009 dmueller@suse.de
- Initial package (v0.6)
